diff flys-backend/src/main/java/de/intevation/flys/model/HWSLine.java @ 5081:1d95391d056b dami

Made it compile again. Removed obsolete imports. Removed C++-alike ';' at end of classes.
author Sascha L. Teichmann <teichmann@intevation.de>
date Sun, 24 Feb 2013 12:56:20 +0100
parents fb7c4ad94bd8
children 2878b816e945
line wrap: on
line diff
--- a/flys-backend/src/main/java/de/intevation/flys/model/HWSLine.java	Thu Feb 21 12:36:30 2013 +0100
+++ b/flys-backend/src/main/java/de/intevation/flys/model/HWSLine.java	Sun Feb 24 12:56:20 2013 +0100
@@ -1,5 +1,9 @@
 package de.intevation.flys.model;
 
+import com.vividsolutions.jts.geom.Geometry;
+
+import de.intevation.flys.model.HWSKind;
+
 import java.io.Serializable;
 
 import javax.persistence.Column;
@@ -9,35 +13,28 @@
 import javax.persistence.OneToOne;
 import javax.persistence.Table;
 
-import org.hibernate.Session;
-import org.hibernate.Query;
 import org.hibernate.annotations.Type;
 
-import de.intevation.flys.backend.SessionHolder;
-import de.intevation.flys.model.HWSKind;
-
-import com.vividsolutions.jts.geom.Geometry;
-
 @Entity
 @Table(name = "hws_lines")
 public class HWSLine implements Serializable {
 
-    private Integer    id;
+    private Integer  id;
 
-    private Integer    ogr_fid;
-    private HWSKind    kind;
-    private FedState  fedState;
-    private River     river;
-    private Integer   offical;
-    private Integer   shore_side;
-    private String    name;
-    private String    path;
-    private String    agency;
-    private String    range;
-    private String    source;
-    private String    status_date;
-    private String    description;
-    private Geometry     geom;
+    private Integer  ogrFid;
+    private HWSKind  kind;
+    private FedState fedState;
+    private River    river;
+    private Integer  offical;
+    private Integer  shoreSide;
+    private String   name;
+    private String   path;
+    private String   agency;
+    private String   range;
+    private String   source;
+    private String   status_date;
+    private String   description;
+    private Geometry geom;
 
     @Id
     @Column(name = "id")
@@ -61,24 +58,22 @@
     }
 
     /**
-     * Get ogr_fid.
+     * Get ogrFid.
      *
-     * @return ogr_fid as Integer.
+     * @return ogrFid as Integer.
      */
     @Column(name = "ogr_fid")
-    public Integer getOgrFid()
-    {
-        return ogr_fid;
+    public Integer getOgrFid() {
+        return ogrFid;
     }
 
     /**
-     * Set ogr_fid.
+     * Set ogrFid.
      *
      * @param ogr_fid the value to set.
      */
-    public void setOgrFid(Integer ogr_fid)
-    {
-        this.ogr_fid = ogr_fid;
+    public void setOgrFid(Integer ogrFid) {
+        this.ogrFid = ogrFid;
     }
 
 
@@ -88,8 +83,7 @@
      * @return offical as Integer.
      */
     @Column(name = "offical")
-    public Integer getOffical()
-    {
+    public Integer getOffical() {
         return offical;
     }
 
@@ -98,30 +92,27 @@
      *
      * @param offical the value to set.
      */
-    public void setOffical(Integer offical)
-    {
+    public void setOffical(Integer offical) {
         this.offical = offical;
     }
 
     /**
-     * Get shore_side.
+     * Get shoreSide.
      *
-     * @return shore_side as Integer.
+     * @return shoreSide as Integer.
      */
     @Column(name = "shore_side")
-    public Integer getShoreSide()
-    {
-        return shore_side;
+    public Integer getShoreSide() {
+        return shoreSide;
     }
 
     /**
-     * Set shore_side.
+     * Set shoreSide.
      *
      * @param shore_side the value to set.
      */
-    public void setShoreSide(Integer shore_side)
-    {
-        this.shore_side = shore_side;
+    public void setShoreSide(Integer shoreSide) {
+        this.shoreSide = shoreSide;
     }
 
     /**
@@ -130,8 +121,7 @@
      * @return name as String.
      */
     @Column(name = "name")
-    public String getName()
-    {
+    public String getName() {
         return name;
     }
 
@@ -140,8 +130,7 @@
      *
      * @param name the value to set.
      */
-    public void setName(String name)
-    {
+    public void setName(String name) {
         this.name = name;
     }
 
@@ -151,8 +140,7 @@
      * @return path as String.
      */
     @Column(name = "path")
-    public String getPath()
-    {
+    public String getPath() {
         return path;
     }
 
@@ -161,8 +149,7 @@
      *
      * @param path the value to set.
      */
-    public void setPath(String path)
-    {
+    public void setPath(String path) {
         this.path = path;
     }
 
@@ -172,8 +159,7 @@
      * @return agency as String.
      */
     @Column(name = "agency")
-    public String getAgency()
-    {
+    public String getAgency() {
         return agency;
     }
 
@@ -182,8 +168,7 @@
      *
      * @param agency the value to set.
      */
-    public void setAgency(String agency)
-    {
+    public void setAgency(String agency) {
         this.agency = agency;
     }
 
@@ -193,8 +178,7 @@
      * @return range as String.
      */
     @Column(name = "range")
-    public String getRange()
-    {
+    public String getRange() {
         return range;
     }
 
@@ -203,8 +187,7 @@
      *
      * @param range the value to set.
      */
-    public void setRange(String range)
-    {
+    public void setRange(String range) {
         this.range = range;
     }
 
@@ -214,8 +197,7 @@
      * @return source as String.
      */
     @Column(name = "source")
-    public String getSource()
-    {
+    public String getSource() {
         return source;
     }
 
@@ -224,8 +206,7 @@
      *
      * @param source the value to set.
      */
-    public void setSource(String source)
-    {
+    public void setSource(String source) {
         this.source = source;
     }
 
@@ -235,8 +216,7 @@
      * @return status_date as String.
      */
     @Column(name = "status_date")
-    public String getStatusDate()
-    {
+    public String getStatusDate() {
         return status_date;
     }
 
@@ -245,8 +225,7 @@
      *
      * @param status_date the value to set.
      */
-    public void setStatusDate(String status_date)
-    {
+    public void setStatusDate(String status_date) {
         this.status_date = status_date;
     }
 
@@ -256,8 +235,7 @@
      * @return description as String.
      */
     @Column(name = "description")
-    public String getDescription()
-    {
+    public String getDescription() {
         return description;
     }
 
@@ -266,8 +244,7 @@
      *
      * @param description the value to set.
      */
-    public void setDescription(String description)
-    {
+    public void setDescription(String description) {
         this.description = description;
     }
 
@@ -278,8 +255,7 @@
      */
     @OneToOne
     @JoinColumn(name = "kind_id")
-    public HWSKind getKind()
-    {
+    public HWSKind getKind() {
         return kind;
     }
 
@@ -288,8 +264,7 @@
      *
      * @param kind the value to set.
      */
-    public void setKind(HWSKind kind)
-    {
+    public void setKind(HWSKind kind) {
         this.kind = kind;
     }
 
@@ -300,8 +275,7 @@
      */
     @OneToOne
     @JoinColumn(name = "fed_state_id")
-    public FedState getFedState()
-    {
+    public FedState getFedState() {
         return fedState;
     }
 
@@ -310,8 +284,7 @@
      *
      * @param fedState the value to set.
      */
-    public void setFedState(FedState fedState)
-    {
+    public void setFedState(FedState fedState) {
         this.fedState = fedState;
     }
 
@@ -322,8 +295,7 @@
      */
     @OneToOne
     @JoinColumn(name = "river_id")
-    public River getRiver()
-    {
+    public River getRiver() {
         return river;
     }
 
@@ -332,8 +304,7 @@
      *
      * @param river the value to set.
      */
-    public void setRiver(River river)
-    {
+    public void setRiver(River river) {
         this.river = river;
     }
 }
@@ -61,24 +58,22 @@
      *
-     * @param ogr_fid the value to set.
+     * @param ogrFid the value to set.
      */
@@ -98,30 +92,27 @@
      *
-     * @param shore_side the value to set.
+     * @param shoreSide the value to set.
      */

http://dive4elements.wald.intevation.org